<div ng-controller="AddFeedCtrl" ng-init="init()">
<div class="header">
	<h1>{{ 'ADDFEED.TITLE' | translate }}</h1>
</div>

<div id="feeds" class="content">
	<div class="pure-g bandeau">
		<div class="pure-u-8-24"><a href="#/config">{{ 'MENU.SETTINGS' | translate }}</a></div>
		<div class="pure-u-8-24"><a href="#/feed">{{ 'MENU.FEEDS' | translate }}</a></div>
		<div class="pure-u-8-24"><a ng-href="{{ pathPrefix }}/logout/">{{ 'MENU.LOG_OUT' | translate }}</a></div>
	</div>

	<form class="zenform centered" ng-submit="addFeed()">
		<input type="url" ng-model="url" size="40" placeholder="http://example.com/feed.xml" autofocus />
		<input type="submit" ng-disabled="isFetching" value="{{ 'ADDFEED.ADD' | translate }}" />
		<p ng-show="url">{{ 'ADDFEED.NOTE' | translate }}</p>
	</form>
</div>
</div>
