<div class="header">
	<h1>{{ 'CONFIG.TITLE' | translate }}</h1>
</div>

<div class="content">
	<div class="pure-g bandeau">
		<div class="pure-u-8-24"><a href="#/config" class="menu-selected">{{ 'MENU.SETTINGS' | translate }}</a></div>
		<div class="pure-u-8-24"><a href="#/feed">{{ 'MENU.FEEDS' | translate }}</a></div>
		<div class="pure-u-8-24"><a ng-href="{{ pathPrefix }}/logout/">{{ 'MENU.LOG_OUT' | translate }}</a></div>
	</div>

	<div ng-controller="ConfigCtrl">
		<form class="zenform zenform-spaced" ng-submit="saveConfig()">
			<label for="config-login">{{ 'CONFIG.LOGIN' | translate }}</label>
			<input id="config-login" type="text" ng-model="config.login" />

			<label for="config-password">{{ 'CONFIG.PASSWORD' | translate }}</label>
			<input id="config-password" type="password" ng-model="config.pw" placeholder="{{ 'CONFIG.PASSWORD.PLACEHOLDER' | translate }}" />
			<div ng-show="config.pw" class="input-details"><i>{{ 'CONFIG.PASSWORD.DETAILS' | translate }}</i></div>

			<label for="config-time-interval">{{ 'CONFIG.TIME_INTERVAL' | translate }}</label>
			<input id="config-time-interval" type="number" ng-model="config.default_refresh_interval" />

			<label for="config-max-entries">{{ 'CONFIG.MAXENTRIES' | translate }}</label>
			<input id="config-max-entries" type="number" ng-model="config.default_max_entries" />

			<label for="config-entries-per-page">{{ 'CONFIG.ENTRIES_PER_PAGE' | translate }}</label>
			<input id="config-entries-per-page" type="number" ng-model="config.default_entries_per_page" />

			<label for="config-highlight-news">{{ 'CONFIG.HIGHLIGHT' | translate }}</label>
			<input id="config-highlight-news" type="checkbox" ng-model="config.default_highlight_news" />

			<br />
			<input type="submit" value="{{ 'CONFIG.SAVE' | translate }}" />
			<input type="button" class="button-grey" ng-click="refetch()" value="{{ 'CONFIG.REFETCH' | translate }}" />
		</form>
	</div>
</div>
