<div ng-controller="EditFeedCtrl" ng-init="init()">
<div class="header">
	<h1>{{ feed.title }}</h1>
</div>

<div id="feeds" class="content">
	<div class="pure-g bandeau">
		<div class="pure-u-8-24"><a href="#/config">{{ 'MENU.SETTINGS' | translate }}</a></div>
		<div class="pure-u-8-24"><a href="#/feed">{{ 'MENU.FEEDS' | translate }}</a></div>
		<div class="pure-u-8-24"><a ng-href="{{ pathPrefix }}/logout/">{{ 'MENU.LOG_OUT' | translate }}</a></div>
	</div>

	<form class="zenform zenform-spaced" ng-submit="saveFeed()">
		<label for="feed-url">{{ 'EDITFEED.URL' | translate }}</label>
		<input id="feed-url" type="url" size="40" ng-model="feed.url" />

		<label for="feed-title">{{ 'EDITFEED.TITLE' | translate }}</label>
		<input id="feed-title" type="text" size="40" ng-model="feed.title" />

		<label for="feed-link">{{ 'EDITFEED.LINK' | translate }}</label>
		<input id="feed-link" type="text" size="40" ng-model="feed.link" />

		<label for="feed-time-interval">{{ 'EDITFEED.REFRESHINTERVAL' | translate }}</label>
		<input id="feed-time-interval" type="number" ng-model="feed.refresh_interval" />

		<label for="feed-max-entries">{{ 'EDITFEED.MAXENTRIES' | translate }}</label>
		<input id="feed-max-entries" type="number" ng-model="feed.max_entries" />

		<label for="feed-entries-per-page">{{ 'EDITFEED.ENTRIES_PER_PAGE' | translate }}</label>
		<input id="feed-entries-per-page" type="number" ng-model="feed.entries_per_page" />

		<label for="feed-highlight-news">{{ 'EDITFEED.HIGHLIGHT' | translate }}</label>
		<input id="feed-highlight-news" type="checkbox" ng-model="feed.highlight_news" />

		<br />
		<input type="submit" value="{{ 'CONFIG.SAVE' | translate }}" />
		<input type="button" class="button-grey" ng-click="refetch()" value="{{ 'CONFIG.REFETCH' | translate }}" />
	</form>
</div>
</div>
