#!/usr/bin/env python
# -*- coding: utf-8 -*-

VERSION = "0.4.0"

# available languages :
LANGUAGES = {
    'en': 'English',
    'es': 'Español',
    'fr': 'Français',
}

DEFAULT_LOGIN = "zenfeed"
DEFAULT_PASSWORD = "zenfeed"
DEFAULT_REFRESH_INTERVAL = 3600
DEFAULT_MAX_ENTRIES = 1000
DEFAULT_ENTRIES_PER_PAGE = 50
DEFAULT_HIGHLIGHT_NEWS = True
