<!doctype html>
<html lang="fr">
<head>
{% block head %}
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<title>{% block title %}Zenfeed.{% endblock %}</title>
	<link rel="icon" type="image/png" href="{{ url_for('static', filename='img/zenicon.png') }}" />
	{% block css %}
	<link rel="stylesheet" href="{{ url_for('static', filename='css/grid.css') }}">
	<link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}">
	{% endblock %}
{% endblock %}
</head>

<body>
{% block body %}{% endblock %}

{% block js %}
<script type="text/javascript" src="{{ url_for('static', filename='js/zenfeed.js') }}" async></script>
{% endblock %}
</body>
</html>
